==> walkers-fabric-1.20.1-4.2-sources.jar: tocraft/walkers/mixin/WolfEntityMixin.java <==
package tocraft.walkers.mixin;

import net.minecraft.class_1299;
import net.minecraft.class_1321;
import net.minecraft.class_1493;
import net.minecraft.class_1937;
import net.minecraft.class_2487;
import net.minecraft.class_2940;
import net.minecraft.class_2943;
import net.minecraft.class_2945;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@SuppressWarnings({})
@Mixin(class_1493.class)
public abstract class WolfEntityMixin extends class_1321 {

    private WolfEntityMixin(class_1299<? extends class_1321> entityType, class_1937 world) {
        super(entityType, world);
    }

    @SuppressWarnings("all")
    @Unique
    private static final class_2940<Boolean> walkers$isSpecial = class_2945.method_12791(class_1493.class, class_2943.field_13323);

    @SuppressWarnings("ConstantConditions")
    @Inject(method = "tick", at = @At("HEAD"))
    public void onTick(CallbackInfo ci) {
        if (this.method_16914() && this.method_5797().getString().equalsIgnoreCase("Patreon"))
            ((class_1493) (Object) this).method_5841().method_12778(walkers$isSpecial, true);
        else
            ((class_1493) (Object) this).method_5841().method_12778(walkers$isSpecial, false);
    }

    @Inject(method = "defineSynchedData", at = @At("RETURN"))
    protected void onInitDataTracker(CallbackInfo ci) {
        ((class_1493) (Object) this).method_5841().method_12784(walkers$isSpecial, false);
    }

    @Inject(method = "addAdditionalSaveData", at = @At("RETURN"))
    protected void onWriteCustomDataToNbt(class_2487 nbt, CallbackInfo ci) {
        nbt.method_10556("isSpecial", ((class_1493) (Object) this).method_5841().method_12789(walkers$isSpecial));
    }

    @Inject(method = "readAdditionalSaveData", at = @At("RETURN"))
    protected void onReadCustomDataFromNbt(class_2487 nbt, CallbackInfo ci) {
        ((class_1493) (Object) this).method_5841().method_12778(walkers$isSpecial, nbt.method_10577("isSpecial"));
    }
}

==> walkers-fabric-1.20.2-4.4.1-sources.jar: tocraft/walkers/mixin/WolfEntityMixin.java <==
package tocraft.walkers.mixin;

import net.minecraft.class_1299;
import net.minecraft.class_1321;
import net.minecraft.class_1493;
import net.minecraft.class_1937;
import net.minecraft.class_2487;
import net.minecraft.class_2940;
import net.minecraft.class_2943;
import net.minecraft.class_2945;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@SuppressWarnings("ALL")
@Mixin(class_1493.class)
public abstract class WolfEntityMixin extends class_1321 {

    private WolfEntityMixin(class_1299<? extends class_1321> entityType, class_1937 world) {
        super(entityType, world);
    }

    @Unique
    private static final class_2940<Boolean> walkers$isSpecial = class_2945.method_12791(class_1493.class, class_2943.field_13323);

    @Inject(method = "tick", at = @At("HEAD"))
    public void onTick(CallbackInfo ci) {
        if (this.method_16914() && this.method_5797().getString().equalsIgnoreCase("Patreon"))
            ((class_1493) (Object) this).method_5841().method_12778(walkers$isSpecial, true);
        else
            ((class_1493) (Object) this).method_5841().method_12778(walkers$isSpecial, false);
    }

    @Inject(method = "defineSynchedData", at = @At("RETURN"))
    protected void onInitDataTracker(CallbackInfo ci) {
        this.method_5841().method_12784(walkers$isSpecial, false);
    }

    @Inject(method = "addAdditionalSaveData", at = @At("RETURN"))
    protected void onWriteCustomDataToNbt(class_2487 nbt, CallbackInfo ci) {
        nbt.method_10556("isSpecial", ((class_1493) (Object) this).method_5841().method_12789(walkers$isSpecial));
    }

    @Inject(method = "readAdditionalSaveData", at = @At("RETURN"))
    protected void onReadCustomDataFromNbt(class_2487 nbt, CallbackInfo ci) {
        ((class_1493) (Object) this).method_5841().method_12778(walkers$isSpecial, nbt.method_10577("isSpecial"));
    }
}
